#!/usr/bin/python
# ======================================================================
# Copyright (C) 2001 and onwards Robert Muth <robert at muth dot org>
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; version 3
# of the License.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
# ======================================================================

# python imports
import logging
import re
import urllib
import urllib2

# available: xml, kml, csv, or json
URL = "http://maps.google.com/maps/geo?q=%s&output=%s"
ACCURACY_THRESHOLD = 8


def GetGeoCodeRaw(address, format="xml", key=None):
    address = urllib.quote_plus(address.encode("utf-8"))
    url = URL % (address, format)
    if key:
        url += "&key=%s" % key
    req = urllib2.Request(url, None)
    try:
      handle = urllib2.urlopen(req)
    except urllib2.HTTPError, err:
        # Errors occur (like 403, 404, etc)
        if err.code < 200:
            raise err
        else:
            header = {}
            if err.hdrs:
                header = err.hdrs
        return "", header, err.code

    header = handle.info()
    data = handle.read()
    handle.close()
    return data, header, 200


def GetGeoCodeForAddress(name, address, key):
    address = ",".join(address)
    address = re.sub("\[[^\[]+\]", "", address)
    if len(address) < 10:
        return None

    data, header, code = GetGeoCodeRaw(address, "csv", key)
    if code != 200:
        logging.error("bad request: %s %s", code, name)
        return None
    code, accuracy, lat, long = data.split(",")
    if int(code) == 610:
        logging.error("bad key")
        return None
    if int(code) != 200:
        logging.error("bad request2: %s %s", code, name)
        return None
    if int(accuracy) < ACCURACY_THRESHOLD:
        logging.error("bad accuracy: %s %s", accuracy, name)
        return None
    logging.info("updating %s", name)
    return lat + " " + long
