#!/usr/bin/env python
# ======================================================================
# Copyright (C) 2001 and onwards  Robert Muth <robert at muth dot org>
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; version 3
# of the License.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
# ======================================================================
"""
Unicode Browser
"""

# python import
import gtk

# local imports
import wutil

# ======================================================================
BAD_UCHAR = { 0:32, 9:32, 10:32, 13:32}

def MakePrintable(uchr):
    return BAD_UCHAR.get(uchr, uchr)

# ======================================================================
class UnicodeBrowserWidget:

    def __init__(self):
        self._labels = []
        self._button_matrix = []
        self._start_uchr = 0
        self._utf8 = "@"
        self._clipboard = gtk.Clipboard(selection="PRIMARY")


        vbox = wutil.MyVBox()
        vbox.show()
        self._widget = vbox

        hbox = wutil.MyHBox()
        vbox.pack_start(hbox, 0, 0)
        hbox.show()

        def Relabel(uchr):
            assert uchr % 256 == 0
            for i in range(16):
                self._labels[i].set_markup("<b>%04x:</b>" % (uchr + i * 16))
                for j in range(16):
                    l = unichr(MakePrintable(uchr + i * 16 + j)).encode("utf-8")
                    self._button_matrix[i][j].set_label(l)
            return

        def ActionValueChanged(dummy_widget, value):
            self._start_uchr = 256 * int(value)
            Relabel(self._start_uchr)
            return

        spinbutton =  wutil.MyOptionSelectRange2(0, 0, 255, 1, 16, 1,
                                                 _("change code page"),
                                                 ActionValueChanged)
        spinbutton.show()
        hbox.pack_start(spinbutton, 0, 0, 0)

#         def ActionSwitchMovePage(widget, delta):
#             self._start_uchr += delta
#             if self._start_uchr < 0: self._start_uchr = 0
#             if self._start_uchr > 65536 - 256:  self._start_uchr = 65536 - 256
#             Relabel(self._start_uchr)
#             return

#         button = wutil.MyButton(" << ")
#         hbox.pack_start(button,0,0,0)
#         button.connect('clicked', ActionSwitchMovePage, -256)
#         button.show()

#         button = wutil.MyButton(" >> ")
#         hbox.pack_start(button,0,0,0)
#         button.connect('clicked', ActionSwitchMovePage, +256)
#         button.show()

        def ActionSendToClipboard(dummy_widget):
            self._clipboard.set_text(self._utf8)
            return

        button = wutil.MyButton(_("Send To Clipboard"), "",
                                ActionSendToClipboard)
        hbox.pack_start(button, 0, 0, 0)
        button.show()

        label = wutil.MyLabel("")
        label.show()
        self._info = label
        hbox.pack_end(label, 0, 0, 0)

        window = wutil.MyScrolledWindow()
        window.show()
        vbox.pack_start(window)


        def ActionCharacterClicked(dummy_widget, offset):
            uchr = self._start_uchr + offset
            self._utf8 = unichr(uchr).encode("utf-8")
            s = "0x"
            for i in self._utf8: s += "%02x" % ord(i)
            self._info.set_markup(
                "<b>dec:</b> %d <b>hex:</b> 0x%x  <b>utf8:</b> %s" %
                (uchr, uchr, s))
            return

        table = gtk.Table(16, 17)
        table.show()
        window.add_with_viewport(table)

        for i in range(16):
            label = wutil.MyLabel("")
            label.show()
            self._labels.append(label)
            table.attach(label, 0, 1, i, i + 1)
            buttons = []
            self._button_matrix.append(buttons)
            for j in range(16):
                button = wutil.MyButton("", "", ActionCharacterClicked, i*16+j)
                button.show()
                table.attach(button, j+1, j+2, i, i + 1)
                buttons.append(button)
        Relabel(self._start_uchr)
        return

    def get_widget(self):
        return self._widget

# ======================================================================
def CreateWidget(dummy_config_id):
    browser = UnicodeBrowserWidget()
    return browser.get_widget()

# ======================================================================

if __name__ == '__main__':
    import sys
    if len(sys.argv) > 1: filename = sys.argv[1]
    window = wutil.MyWindow(_('ASCII'))
    window.add(CreateWidget("wascii"))
    window.show()
    wutil.CreateAndRunApp(window)

# ======================================================================
# eof
# ======================================================================
