#!/usr/bin/env python
# ======================================================================
# Copyright (C) 2001 and onwards Robert Muth <robert at muth dot org>
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; version 3
# of the License.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
# ======================================================================

"""
Winzig Alarm Clock
"""

# python imports
import time
import gtk
import gobject

# local import
import wutil
import wconfig

# ======================================================================
class AlarmClock:

    def __init__(self):
        self._time = None
        self._date = None
        self._widget = None
        self._alarm_h = -1
        self._alarm_m = -1

        vbox = wutil.MyVBox()
        vbox.show()
        self._widget = vbox

        label = wutil.MyLabel("No Time")
        label.set_name("clock_time")
        vbox.pack_start(label, 0, 0)
        label.show()
        self._time = label

        label = wutil.MyLabel("No Date")
        label.set_name("clock_date")
        vbox.pack_start(label, 0, 0)
        label.show()
        self._date = label

        hbox = wutil.MyHBox()
        hbox.show()
        vbox.pack_start(hbox, 0, 0)

        menubar = gtk.MenuBar()
        menubar.show()
        hbox.pack_start(menubar,0,0)
        menutitle = wutil.MyMenuTitle("H",
                                      _("select alarm hour"))
        menutitle.show()
        menubar.append(menutitle)
        self._alarm_h_menu = menutitle

        menu = gtk.Menu()
        menutitle.set_submenu(menu)

        def SetAlarmHour(dummy_widget, h):
            self._alarm_h_menu.get_child().set_text("%2d" % h)
            print h
            return

        for x in range(24):
            # the string is important (forces label creation)
            item = gtk.MenuItem(str(x))
            item.show()
            item.connect("activate", SetAlarmHour, x)
            menu.append(item)


        label = wutil.MyLabelWithMarkup("<b>:</b>")
        hbox.pack_start(label, 0)
        label.show()

        menubar = gtk.MenuBar()
        menubar.show()
        hbox.pack_start(menubar, 0, 0)

        menutitle = wutil.MyMenuTitle("M",
                                      _("select alarm minute"))
        menutitle.show()
        menubar.append(menutitle)
        self._alarm_m_menu = menutitle

        menu = gtk.Menu()
        menutitle.set_submenu(menu)

        def SetStartMinute(dummy_widget, m):
            self._alarm_m_menu.get_child().set_text("%02d" % m)
            print m
            return

        for x in range(0, 60, 2):
            # the string is important (forces label creation)
            item = gtk.MenuItem("%02d" % x)
            item.show()
            item.connect("activate", SetStartMinute, x)
            menu.append(item)


        self.Update()
        return

    def Update(self, dummy=None):
        the_time = time.localtime(time.time())
        timestr = time.strftime(wconfig.GetConfig('wclock:time_fmt'), the_time)
        datestr = time.strftime(wconfig.GetConfig('wclock:date_fmt'), the_time)

        self._date.set_markup(datestr)
        self._time.set_markup(timestr)
        try:
            gobject.timeout_add(wconfig.GetConfig('wclock:updatems'), self.Update, None)
        except:
            gtk.timeout_add(wconfig.GetConfig('wclock:updatems'), self.Update, None)
        return

    def get_widget(self):
        return self._widget

# ======================================================================
def Main():
    clock = AlarmClock()
    window = wutil.MyWindow(_('ALARM'))
    window.add(clock.get_widget())
    window.show()
    wutil.CreateAndRunApp(window)
    return


# ======================================================================
if __name__ == '__main__':
    Main()

# ======================================================================
# eof
# ======================================================================




