#!/usr/bin/env python
# ======================================================================
# Copyright (C) 2001 and onwards Robert Muth <robert at muth dot org>
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; version 3
# of the License.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
# ======================================================================

"""
winzig's global config file
there is also a local config file in Data/localconfig.py

NOTE: you probably should edit the local config file
"""

# python imports
import os
import sys
import urllib

# local imports
import wutil
# ======================================================================
#
# ======================================================================
try:
    datapath = os.environ['WINZIG_DATA_PATH']
except:
    datapath = "Data"


def MakePath(filename):
    return os.path.join(datapath, filename)

# ======================================================================
#
# ======================================================================

Config = {}

def LoadLocalConfig():
    sys.path.insert(0, datapath)
    try:
        import winziglocal
    except Exception, e:
        print "no local config found: ", e
        pass

def GetConfig(t):
    return Config[t]


def GetAppConfig(app, tag):
    return Config[app + ":" + tag]

# ======================================================================
# available widget config
# ======================================================================
# it is possible to have multiple tuples with
# the same module-name but different config or tab names
# This is useful for example if you want to keep
# multiple address books around
Config['winzig:activetabs'] =  [
    {"title": "Contact",
     "module": "wcontacts",
     "config": "wcontacts",
     "reload": 1,
     },
    {"title": "Calc",
     "module": "wcalculator",
     "config": "wcalculator",
     "reload": 0,
     },
    {"title": "Note",
     "module": "wnotes",
     "config": "wnotes",
     "reload": 1,
     },
    {"title": "Todo",
     "module": "wtodo",
     "config": "wtodo",
     "reload": 1,
     },
    {"title": "Cal",
     "module": "wcalendar",
     "config": "wcalendar",
     "reload": 1,
     },
    {"title": "Ascii",
     "module": "wascii",
     "config": "wascii",
     "reload": 0,
     },
    {"title": "Rgb",
     "module": "wrgb",
     "config": "wrgb",
     "reload": 0,
     },
    {"title": "Weather",
     "module": "weather",
     "config": "weather",
     "reload": 0,
     },
    {"title": "Dict",
     "module": "wdict",
     "config": "wdict",
     "reload": 1,
     },
    {"title": "Journal",
     "module": "wjournal",
     "config": "wjournal",
     "reload": 1,
     },
    {"title": "Exec",
     "module": "wexecutor",
     "config": "wexecutor",
     "reload": 0,
     },
    {"title": "About",
     "module": "wabout",
     "config": "wabout",
     "reload": 0,
     },
    ]

# ======================================================================
# contacts widget config
# ======================================================================
# name of the db
Config['wcontacts:database'] = MakePath("contacts.db")
# which tags will have a button for extra action
Config['wcontacts:electric_tags'] = ["a1", "a4",
                                     "g1", "g2",
                                     "p1", "p2",
                                     "e1", "e2",
                                     "m1", "m2",
                                     "w1", "w2",
                                     ]
MAPS_URL = "http://maps.google.com/maps?q="
BROWSER = "firefox"

def elecelectric_cb(tag, record):
    if tag in ["p1", "p2", "m1", "m2"]:
        wutil.gui_error("phone app for %s not configured" % record[tag])
    elif tag in ["e1", "e2"]:
        wutil.gui_error("email app for %s not configured" % record[tag])
    elif tag in ["g1", "g2"]:
        wutil.gui_error("geo app for %s not configured" % record[tag])
    elif tag in ["w1", "w2"]:
        os.system("%s %s" % (BROWSER, record[tag]))
    elif tag == "a1":
        loc = record.get("a1") + " " + record.get("a2") + " " + record.get("a3")
        os.system("%s %s" % (BROWSER, MAPS_URL + urllib.quote_plus(loc)))
    elif tag == "a4":
        loc = record.get("a4") + " " + record.get("a5") + " " + record.get("a6")
        os.system("%s %s" % (BROWSER, MAPS_URL + urllib.quote_plus(loc)))
    else:
        wutil.gui_error("unknown app for tag: %s" % tag)
    return

Config['wcontacts:electric_cb'] = elecelectric_cb
# ======================================================================
# dictionary widget config
# ======================================================================
def CreateDictionaries():
    dictbase = ""
    dictionaries = []
    dictionaries.append(
          ( "wordnet (online)",
            "get",
            "http://wordnet.princeton.edu/perl/webwn?s=",
            r".lexical. relations"
            r"(.*)"
            r"WordNet home page"))

    if os.path.isfile("/usr/local/WordNet-2.1/bin/wn"):
        dictionaries.append(
              ("wordnet (local)",
               "shell",
               "/usr/local/WordNet-2.1/bin/wn %(words)s -synsv -over"))


    for (name, db) in [("en -> de (local)", dictbase + "/dictionary.ed"),
                       ("de -> en (local)", dictbase + "/dictionary.de")]:
        if os.path.isfile(db):
            dictionaries.append(
                ("en -> de (local)",
                 "shell",
                 "agrep -d '$$' '%(words)s' " + db))

    for db in ["de|en","en|de","es|en","en|es"]:
        name = "%s -> %s (Google)" % tuple(db.split("|"))
        dictionaries.append(
              ( name,
                "get",
                "http://translate.google.com/translate_t?langpair=%s&text=" % db,
                r"<div id=result_box [^>]+>"
                r"([^<]*)"
                r"</div"))

    for name, url in [("de <-> es (osola)",
                       "http://dix.osola.com/index.php?search="),
                      ("es <-> en (osola)",
                       "http://www.dictionary-spanish.info/index.php?search="),
                      #("de <-> en (osola)",
                      #"http://www.dictionary-german.info/index.php?search"),
                      ]:
        dictionaries.append(
              ( name,
                "get",
                url,
                r"<!--page table-->"
                r"(<table width.*)"
                r"Did you find an error"))
    return dictionaries

Config['wdict:dictionaries'] = CreateDictionaries()
Config['wdict:log'] =  MakePath("dict.log")
Config['wdict:maxlinelen'] = 50

# ======================================================================
# misc widget config
# ======================================================================
Config['wnotes:database'] = MakePath("notes.db")

Config['wjournal:database'] = MakePath("journal.db")

Config['wtodo:database'] =  MakePath("todo.db")

# get the 4 letter weather station codes from
# http://weather.noaa.gov
Config['weather:stations'] =  [(" New York ", "KNYC")]

Config['wcalendar:week_start_monday'] = True
Config['wcalendar:database'] =  MakePath("calendar.db")

Config['wclock:updatems'] = 30000
Config['wclock:time_fmt'] = "<b><big>%H:%M</big></b>"
Config['wclock:date_fmt'] = "\n<b>%a  %d %b %Y</b>\n"

Config['wrgb:paths'] = ['/usr/share/X11/rgb.txt',
                        '/usr/lib/X11/rgb.txt',
                        '/etc/X11/rgb.txt',
                        '/usr/X11R6/lib/X11/rgb.txt',
                        MakePath("rgb.txt")]



COMPLETION_DELAY = 5
XTERM = "xterm -e"


Config['wexecutor:commands'] = [
    {"title": 'sync winzig (svn update)',
      "command": '%s "'
      'cd %s;'
      'svn update;'
      'svn status -v *.db *.log;'
      'read -t %d -n 1"' % (XTERM, datapath, COMPLETION_DELAY),
      "reload": 1
      },

     {"title": 'sync winzig (svn commit)',
      "command": '%s "'
      'cd %s;'
      'svn commit -m \'\';'
      'svn status *.db *.log;'
      'read -t %d -n 1"' % (XTERM, datapath, COMPLETION_DELAY),
      "reload": 1
      },

     {"title": 'sync winzig (svn diff)',
      "command": '%s "'
      'cd %s;'
      'svn diff;'
      'read  -n 1"' % (XTERM, datapath),
      "reload": 0
      },

     {"title": 'airodump-ng',
      "command": '%s "/usr/sbin/airodump-ng"' % XTERM,
      "reload": 0
      },

     {"title": 'tcpdump',
      "command": '%s "/usr/sbin/tcpdump -i eth0"' % XTERM,
      "reload": 0
      },

    {"title": 'test message',
    "command": 'xmessage -nearmouse cool&',
     "reload": 0
     },
    ]



# Give local configs a chance to overwrite global condfigs
LoadLocalConfig()

# ======================================================================
# eof
# ======================================================================
