#!/usr/bin/env python
# ======================================================================
# Copyright (C) 2001 and onwards Robert Muth <robert at muth dot org>
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; version 3
# of the License.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
# ======================================================================
"""
Winzig's Weather Widget
"""
# python imports
import re
import urllib2
import threading
import Queue

# local imports
import wconfig
import wutil

_WEATHER_URL = "http://weather.noaa.gov/pub/data/observations/metar/decoded/%s.TXT"
# ======================================================================
def GetWeatherDate(station):
    fp = urllib2.urlopen(_WEATHER_URL % station)
    data = fp.read()
    fp.close()
    return data

# ======================================================================
def SplitLongLine(line, lo, mid, hi):
    lines = []
    while len(line) > hi:
        index = mid
        for char in [")", ",", " "]:
            i = line.find(char, lo)
            if i >= 0 and i <= hi:
                index = i
                break
        lines.append(line[0:index+1])
        line = "\t" + line[index+1:]
    if line:
        lines.append(line)
    return lines

# ======================================================================
def Shorten(line):
    return line.replace("United States", "USA") # preserve space

# ======================================================================
def Highlite(line):
    if  line.find(":") > 0:
        return "<b>" + line.replace(":", "</b>:", 1)
    else:
        return line

# ======================================================================
def ReformatTitleLine(s):
    match = re.search(r"[ 0-9-NESWM]+$", s)
    assert match
    s = s[:match.start()]
    return Shorten(s)

def ReformatDateLine(s):
    match = re.search(r"^.* / ", s)
    assert match
    return match.group()[:-3]
# ======================================================================
def Reformat(data):
    markup = []

    lines = data.split("\n")
    title = ReformatTitleLine(lines.pop(0))
    date = ReformatDateLine(lines.pop(0))
    markup += SplitLongLine("<big><b>" + title + "</b></big>", 30, 45, 60)
    markup += SplitLongLine("<big><b>" + date + "</b></big>", 30, 45, 60)
    markup.append("")
    for line in  lines:
        markup += SplitLongLine(Highlite(line), 30, 45, 60)

    return "\n".join(markup)


# ======================================================================
GlobalQueue = Queue.Queue()

def StationWorker(widget):
    global GlobalQueue
    while 1:
        station = GlobalQueue.get()
        widget.set_markup("Looking for station %s" % station)
        try:
            data = Reformat(GetWeatherDate(station))
        except Exception, err:
            widget.set_markup("Failed looking up station: %s\n%s" %
                              (station,str(err)))
        else:
            widget.set_markup(data)

# ======================================================================
def CreateWidget(config_id):
    global GlobalQueue

    vbox = wutil.MyVBox()
    vbox.show()

    # the buttons for the various cities
    hbox = wutil.MyHBox()
    hbox.show()
    vbox.pack_start(hbox, 0, 0)

    stations = wconfig.GetAppConfig(config_id, 'stations')
    def UpdateWeather(dummy, station):
        GlobalQueue.put(station)
        return

    for text, station in stations:
        button = wutil.MyButton(text, "", UpdateWeather, station)
        hbox.pack_start(button, 0, 0)
        button.show()

    # window for label
    window = wutil.MyScrolledWindow()
    vbox.pack_start(window)
    window.show()

    # trickery to keep label in upper left corner
    hbox = wutil.MyHBox()
    hbox.show()
    window.add_with_viewport(hbox)

    # trickery to keep label in upper left corner
    vvbox = wutil.MyVBox()
    vvbox.show()
    hbox.pack_start(vvbox, 0, 0)

    label = wutil.MyLabel("")
    label.show()
    vvbox.pack_start(label, 0, 0)


    t = threading.Thread(target=StationWorker, args=(label,))
    t.setDaemon(True)
    t.start()

    GlobalQueue.put(stations[0][1])
    return vbox

# ======================================================================
if __name__ == '__main__':
    window = wutil.MyWindow(_('WEATHER'))
    window.add(CreateWidget("weather"))
    window.show()
    wutil.CreateAndRunApp(window)

# ======================================================================
# eof
# ======================================================================




