#!/usr/bin/env python
# ======================================================================
# Copyright (C) 2001 and onwards Robert Muth <robert at muth dot org>
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; version 3
# of the License.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
# ======================================================================
"""
    Winzig's Executor Widget
"""

__all__ = ["CreateWidget"]

# python imports
import gtk
import sys
import os
import subprocess

# local imports
import wconfig
import wutil

# ======================================================================
class Process:

    def __init__(self):
        self._process = None

        return


    def Run(self, args):
        if self._process:
            print "process exist"
            return
        self._process =subprocess.Popen(args,
                                        stdin=subprocess.PIPE,
                                        stderr=subprocess.STDOUT,
                                        stdout=subprocess.PIPE)
        return

    def kill(self):
        if not self._process:
            print "no process"
            return
        os.kill(self._process.pid)
        return

def CreateWidget(config_id):
    commands =  wconfig.GetAppConfig(config_id, 'commands')
    process = Process()

    text = None
    vbox = wutil.MyVBox()
    vbox.show()

    for command in commands:

        hbox = wutil.MyHBox()
        hbox.show()
        vbox.pack_start(hbox, 0, 0)

        def ExecuteCommand(dummy, command):
            buffer = text.get_buffer()
            if command["reload"]:
                if not wutil.PopUpDirtyDialog("run command"):
                    buffer.insert_at_cursor("command not run")
                    return
            buffer.insert_at_cursor("running %s\n" % command["command"])
            os.system(command["command"])
            if command["reload"]:
                notebook = wutil.GetNotebook()
                apps = wconfig.GetAppConfig('winzig', 'activetabs')
                buffer.insert_at_cursor("reloading apps\n")
                wutil.PopulateNotebookWithWidgets(notebook, apps, 1)
            return

        button = wutil.MyButton(command["title"],
                                "",
                                ExecuteCommand, command)
        vbox.pack_start(button, 0, 0)
        button.show()


    window = wutil.MyScrolledWindow()
    window.show()
    vbox.pack_start(window)

    # trickery to keep label in upper left corner
    hbox = wutil.MyHBox()
    hbox.show()
    window.add_with_viewport(hbox)

    # trickery to keep label in upper left corner
    vvbox = wutil.MyVBox()
    vvbox.show()
    hbox.pack_start(vvbox)

    text = wutil.MyTextView(None)
    text.show()
    vvbox.pack_start(text)

    return vbox

# ======================================================================
if __name__ == '__main__':
    window = wutil.MyWindow(_('EXEC'))
    window.add(CreateWidget("wexecutor"))
    window.show()
    wutil.CreateAndRunApp(window)

# ======================================================================
# eof
# ======================================================================




