#!/usr/bin/env python
# ======================================================================
# Copyright (C) 2001 and onwards Robert Muth <robert at muth dot org>
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; version 3
# of the License.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
# ======================================================================
"""
Winzig Toplevel Shell
All widgets are separatly executable
"""

# python imports
import gc
import gtk

import logging
import re
import sys

# local imports
import wutil
import wconfig
import wversion

# for nokia 770/800/810
try:
    import hildon
    import os
    import osso
    hildon_support = 1
except ImportError:
    hildon_support = 0
# ======================================================================
def NokiaInit(notebook):
    osso_c = osso.Context("org.muth.winzig", wversion.version, False)

    program = hildon.Program()
    window = hildon.Window()

    #mainview = hildon.AppView("Winzig PIM");

    #app.set_appview(mainview)
    window.set_title("Winzig")
    # next line is important for Maemos task icon
    # using StartupWMClass in .desktop file
    window.set_wmclass("winzig", "winzig")
    #mainview.set_fullscreen(0)
    #mainview.set_fullscreen_key_allowed(True)
    #app.show()
    gtk.Container.add(window, notebook)
    window.show()
    wutil.CreateAndRunApp(window)
    return

# ======================================================================
def RegularInit(notebook):

    vbox = wutil.MyVBox()
    vbox.show()
    vbox.pack_start(notebook)

    window = gtk.Window()
    window.set_title('winzig')
    window.add(vbox)
    window.show()

    wutil.CreateAndRunApp(window)
    return

# ======================================================================
def main():
    notebook = wutil.MyNotebook()
    notebook.show()
    # gc.collect()
    #print "delete tab %d" % notebook.get_n_pages()
    apps = wconfig.GetAppConfig('winzig', 'activetabs')
    logging.info("creating notebook with %d apps", len(apps))
    wutil.PopulateNotebookWithWidgets(notebook, apps)
    logging.info("notebook complete")
    wutil.SetNotebook(notebook)

    if hildon_support:
        NokiaInit(notebook)
    else:
        RegularInit(notebook)

# ======================================================================
if __name__ == '__main__':
    debug = 0
    profile = 0

    if "-debug" in sys.argv:
        debug = 1

    if "-profile" in sys.argv:
        profile = 1

    logformat=("%(levelname)s:"
               "%(module)s:"
               "%(lineno)d:"
               "%(threadName)s:"
               "%(message)s")

    if debug:
        logging.basicConfig(level=logging.INFO, format=logformat)
    else:
        logging.basicConfig(level=logging.WARNING, format=logformat)

    if profile:
        import cProfile
        import pstats
        cProfile.run('main()','xxx')
        p = pstats.Stats('xxx')
        p.sort_stats('cumulative').print_stats(50)
        p.sort_stats('time').print_stats(50)
    else:
        main()


# ======================================================================
## eof
# ======================================================================
