#!/usr/bin/env python
# ======================================================================
# Copyright (C) 2001 and onwards Robert Muth <robert at muth dot org>
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; version 3
# of the License.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
# ======================================================================

"""
Winzig's X11 color viewer
"""

# python imports
import os

# local imports
import wutil
import wconfig

# ======================================================================
Colors = {}

def InverseColor(color):
    index = 0xffffff - int(color, 16)
    return "%06x" % index

# ======================================================================
def ReadandProcessRgbFile(filename):
    try:
        for line in file(filename):
            if line[0] == "!": continue
            tokens = line.split()
            value = "%02x%02x%02x" % (int(tokens[0]), int(tokens[1]), int(tokens[2]))
            name  = " ".join(tokens[3:])
            new_list = Colors.get(value, [])
            new_list.append(name)
            Colors[value] = new_list
        return 1
    except IOError, e:
        print _("no rgb file found or error during processing"), e
        return 0
    except:
        print _("unexpected event")
        return 0

# ======================================================================
def BuildRgbString():
    s = "<span font_desc='Fixed 12'>\n"
    keys = Colors.keys()
    keys.sort()

    for key in keys:
        key2 = InverseColor(key)
        l = ""
        for combo in [ (key, key2), (key, "000000"), (key, "ffffff")]:
            l+= "<span background='#%s' foreground='#%s'>normal</span> " % combo
        for combo in [ (key2, key), (key2, "000000"), (key2, "ffffff")]:
            l+= "<span background='#%s' foreground='#%s'>inverse</span> " % combo
        l += key + " " + ",".join([ "'" + n + "'" for n in Colors[key] ]) + "\n"

        s += l
    s += "</span>\n"
    return s

# ======================================================================
def CreateWidget(config_id):
    rgb_files = wconfig.GetAppConfig(config_id, 'paths')
    for f in  rgb_files:
        if not os.path.exists(f): continue
        ReadandProcessRgbFile(f)

    s = BuildRgbString()

    window = wutil.MyScrolledWindow()
    window.show()

    label = wutil.MyLabelWithMarkup(s)
    label.show()

    window.add_with_viewport(label)

    return window

# ======================================================================
if __name__ == '__main__':
    import sys
    if sys.platform == 'win32':
        print _("the wrgb app does not work on windows")
        sys.exit(-1)
    window = wutil.MyWindow(_('RGB'))
    window.add(CreateWidget("wrgb"))
    window.show()
    wutil.CreateAndRunApp(window)

# ======================================================================
# eof
# ======================================================================
